<?php
/*-----------------------------------------------------------*
/* 			Theme Option Backup
/*-----------------------------------------------------------*/

if( !defined( 'ABSPATH' ) ) exit;
if( !class_exists( 'CHURCH_THEME_BACKUP' ) ) :

class CHURCH_THEME_BACKUP {
    /**
	 * Protected variable.
	 */
    protected $church_backup_page = "";
	/**
	 * Construct.
	 */
	public function __construct(){
		add_action( 'admin_init', array( $this ,'church_backup_register_setting' ) );
		add_action( 'admin_menu', array( $this ,'church_backup_page' ) );
		add_action( 'admin_init', array( $this, 'praise_church_process_settings_import' ) );
		add_action( 'admin_init', array( $this, 'praise_church_process_settings_export' ) );
	}	
	/** 
	 * Register Setting.
	 */
	public function church_backup_register_setting(){
		register_setting( 'ease_options_group', 'ease_options' );
	}
	/**
	 * Add Theme Page Or Menu.
	 */
	public function church_backup_page(){
	add_submenu_page( THEME_TEXT_DOMAIN, ADMIN_THEME_OPTION_BACKUP_TITLE, ADMIN_THEME_OPTION_BACKUP_TITLE, 'manage_options', THEME_TEXT_DOMAIN.'_backup', array( $this,'church_backup_option_page') );
	}
	/**
	 * Main Admin page.
	 */
	public function church_backup_option_page(){
	?>  
<div class="wrap">
<div class="metabox-holder">
<div class="postbox">
    <h3><span><?php _e( 'Export Settings', 'praise_church'); ?></span></h3>
    <div class="inside">
        <p><?php _e( 'Export the plugin settings for this site as a .json file. This allows you to easily import the configuration into another site.', 'praise_church' ); ?></p>
        <form method="post">
            <p><input type="hidden" name="praise_church_action" value="export_settings" /></p>
            <p>
                <?php wp_nonce_field( 'praise_church_export_nonce', 'praise_church_export_nonce' ); ?>
                <?php submit_button( __( 'Export', 'praise_church' ), 'secondary', 'submit', false ); ?>
            </p>
        </form>
    </div><!-- .inside -->
</div><!-- .postbox -->

<div class="postbox">
    <h3><span><?php _e( THEME_NAME.' Import Settings', 'praise_church' ); ?></span></h3>
    <div class="inside">
    <p><?php _e( 'Import the settings from a .json file. This file can be obtained by exporting the settings on another site using the form above.', 'praise_church' ); ?></p>
        <form method="post" enctype="multipart/form-data">
            <p>
                <input type="file" name="import_file"/>
            </p>
            <p>
                <input type="hidden" name="praise_church_action" value="import_settings" />
                <?php wp_nonce_field( 'praise_church_import_nonce', 'praise_church_import_nonce' ); ?>
                <?php submit_button( __( 'Import', 'praise_church' ), 'secondary', 'submit', false ); ?>
            </p>
        </form>
    </div><!-- .inside -->
</div><!-- .postbox -->
</div><!-- .metabox-holder -->	
</div>
    <?php
	}	
	
	/**
	 * Process a settings export that generates a .json file of the shop settings
	 */
	public function praise_church_process_settings_export() {
		if( empty( $_POST['praise_church_action'] ) || 'export_settings' != $_POST['praise_church_action'] )
			return;
		if( ! wp_verify_nonce( $_POST['praise_church_export_nonce'], 'praise_church_export_nonce' ) )
			return;
		if( ! current_user_can( 'manage_options' ) )
			return;
		$settings = get_option( 'ease_options' );
		ignore_user_abort( true );
		nocache_headers();
		header( 'Content-Type: application/json; charset=utf-8' );
		header( 'Content-Disposition: attachment; filename='.THEME_TEXT_DOMAIN.'-setting-export-' . date( 'm-d-Y' ) . '.json' );
		header( "Expires: 0" );
		echo json_encode( $settings );
		exit;
	}

	/**
	 * Process a settings import from a json file
	 */
	public function praise_church_process_settings_import() {
		if( empty( $_POST['praise_church_action'] ) || 'import_settings' != $_POST['praise_church_action'] )
			return;
		if( ! wp_verify_nonce( $_POST['praise_church_import_nonce'], 'praise_church_import_nonce' ) )
			return;
		if( ! current_user_can( 'manage_options' ) )
			return;
		$extension = end( explode( '.', $_FILES['import_file']['name'] ) );
		if( $extension != 'json' ) {
			wp_die( __( 'Please upload a valid .json file', 'praise_church' ) );
		}
		$import_file = $_FILES['import_file']['tmp_name'];
		if( empty( $import_file ) ) {
			wp_die( __( 'Please upload a file to import', 'praise_church' ) );
		}
		// Retrieve the settings from the file and convert the json object to an array.
		$settings = (array) json_decode( file_get_contents( $import_file ) );
		update_option( 'ease_options', $settings );
		wp_safe_redirect( admin_url( 'admin.php?page='.THEME_TEXT_DOMAIN ) ); exit;
	}
	
}
endif;
/** 
 * $obj using class contstruct.
 */
$obj = new CHURCH_THEME_BACKUP;
?>