<?php
/**
* Church functions and definitions.
*
* @package Church
*/
if ( !isset( $content_width ) ) :
	$content_width = 640; 	// pixels 
endif;

if ( !function_exists( 'church_setup' ) ) {

 	  function church_setup() {
		  
		/* Load translation domain ---------------------------------------------*/
		load_theme_textdomain( 'praise_church', get_template_directory() . '/language' );

		/* Register Menus ------------------------------------------------------*/	
		register_nav_menus( array('primary'   => esc_html__( 'Primary Menu', 'praise_church' ), ));
		register_nav_menus( array('user_link' => esc_html__( 'Useful Links', 'praise_church' ), ));	

		// Add theme support for Automatic Feed Links
		add_theme_support( 'automatic-feed-links' );	

		// Add theme support for document Title tag
		add_theme_support( 'title-tag' );

		// @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		add_theme_support( 'post-thumbnails' );
		add_image_size('ministry', 360, 196, true); 
		add_image_size('church-pastor', 155, 178, true); 
		add_image_size( 'admin-list-thumb', 80, 80, true); //admin thumbnail preview
		add_image_size( 'album-grid', 450, 450, true );		
		
		// Add theme support for HTML5 Semantic Markup
		add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );

		// Add theme support for Post Formats
		add_theme_support( 'post-formats', array( 'status', 'quote', 'gallery', 'image', 'video', 'audio', 'link', 'aside', 'chat' ) );

		// Add theme support for Custom Background
		$background_args = array(
			'default-color'          => 'ffffff',
			'default-image'          => '',
		);

		add_theme_support( 'custom-background', $background_args );
	}	
	
	add_action( 'after_setup_theme', 'church_setup' ); 
} 
/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */ 
if( !function_exists('church_widgets_init') ){

	 function church_widgets_init() {
		register_sidebar( array(
			'name'          => esc_html__( 'Primary Sidebar', 'praise_church' ),
			'id'            => 'primary_sidebar',
			'description'   => '',
			'before_widget' => '<div class="col-md-12"><div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
		register_sidebar( array(
			'name'          => esc_html__( 'Custom Sidebar', 'praise_church' ),
			'id'            => 'custom_sidebar',
			'description'   => '',
			'before_widget' => '<div class="col-md-12"><div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
		register_sidebar( array(
			'name'          => esc_html__( 'Twitter', 'praise_church' ),
			'id'            => 'secoundary_sidebar',
			'description'   => '',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );		
		register_sidebar(array(
			'name' => 'WooCommerce Sidebar', 
			'id'            => 'woocommerce_sidebar',
			'description'   => '',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>', 
			'before_title'  => '<h2 class="woocommers-widget-title">', 
			'after_title'   => '</h2>'
		));		
	 }
	 
	 add_action( 'widgets_init', 'church_widgets_init' ); 
}
/**
 * Register abel, Permanent+Marker Google font for Church.
 *
 * @since Church
 *
 * @return string
 */
if( !function_exists('church_fonts') ){
	
	function church_fonts() {
		$fonts_url = '';
	
		/* Translators: If there are characters in your language that are not
		* supported by Lora, translate this to 'off'. Do not translate
		* into your own language.
		*/
		$font_first = _x( 'on', 'abel font: on or off', 'praise_church' );
		$font_sec   = _x( 'on', 'Permanent Marker font: on or off', 'praise_church' );
	
		if ( 'off' !== $font_first || 'off' !== $font_sec  ) {
			$font_families = array();
	
			if ( 'off' !== $font_first ) {
				$font_families[] = 'Abel';
			}
	
			if ( 'off' !== $font_sec ) {
				$font_families[] = 'Permanent Marker';
			}
	
			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( 'latin,latin-ext' ),
			);
	
			$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
		}
	
		return esc_url_raw( $fonts_url );
	}
}
if( !function_exists( 'owl_scripts' ) ){
	
	function owl_scripts(){	
		wp_enqueue_style( 'church_owl_carousel_css', get_template_directory_uri() . '/css/owlcarousel/owl.carousel.css');	
		wp_enqueue_script( 'church_owl_carousel_js', get_template_directory_uri() . '/js/owlcarousel/owl.carousel.js', array('jquery'), null, true );
	}
}
if( !function_exists( 'magnific_popup' ) ){
					 
	function magnific_popup(){
		// magnific popup.js
		wp_enqueue_script( 'church_magnific_js', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array(), null, true );	
		// magnific popup script
		wp_enqueue_script( 'church_popup_js', get_template_directory_uri() . '/js/popup-portfolio.js', array('jquery'), null, true );			
	}					
}
if( !function_exists( 'img_load' ) ){
	
	function img_load(){
		// church image load.js		
		wp_enqueue_script( 'church_images_loaded', get_template_directory_uri() . '/js/imagesloaded.pkgd.min.js', array('jquery'), true  );
		// church masonry.js
		wp_enqueue_script( 'church_masonry_js', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array('jquery'), true  );
	}
}
/**
 * Enqueue scripts and styles.
 */
if( !function_exists('church_scripts') ){

	 function church_scripts() {	

		if( !is_admin() ) :

		/* Enqueue Styles ---------------------------------------------------*/

		// Add custom fonts, used in the main stylesheet.
		wp_enqueue_style( 'church_fonts', church_fonts(), array(), null );
		// Bootstrap 
		wp_enqueue_style( 'church_bootstrap_css', get_template_directory_uri() .'/css/bootstrap.min.css');	
		// Custom Style	
		wp_enqueue_style( 'church_custom_style', get_template_directory_uri() . '/css/custom-style.css');
		// Font-awesome icon
		wp_enqueue_style( 'church_fontawesome', get_template_directory_uri() . '/css/font-awesome.min.css');
		// TinyMCE Editor Style
		wp_enqueue_style( 'church_add_editor_style', get_template_directory_uri() . '/css/add_editor_style.css');
		
	
		if ( is_rtl() ) {
			// is_rtl
			wp_enqueue_style( 'church_rtl_style', get_template_directory_uri() . '/rtl.css' );
			// Custom script 
			wp_enqueue_script( 'church_rtl_script', get_template_directory_uri() . '/js/rtl/script-rtl.js', array('jquery'), null, true );

		}else {
			// stylesheet
			wp_enqueue_style( 'church_stylesheet', get_stylesheet_uri());
			// Custom script 
			wp_enqueue_script( 'church_script', get_template_directory_uri() . '/js/script.js', array('jquery'), null, true );
		}

		/* Enqueue Scripts ---------------------------------------------------*/
		
		// Bootstrap.js
		wp_enqueue_script( 'church-bootstrap-js', get_template_directory_uri() . '/js/bootstrap.js', array('jquery'), true );
		
		
		
		/* Page-template Scripts ---------------------------------------------------*/

		if( is_page_template('page-template/home.php') ) {
			// owl-script
			owl_scripts();
			wp_enqueue_style( 'church_magnific_css', get_template_directory_uri() . '/css/magnific-popup.css');	
			// magnific popup script.
			magnific_popup();
		}
		if( is_page_template('page-template/masonry-two-column.php') || 
			is_page_template('page-template/masonry-three-column.php') || is_home() ) {
			// owl-script
			owl_scripts();				
			// image load  jquery.
			img_load();
		}
		if( is_page_template('page-template/donation.php') ){			
			// nouislider stylesheet 
			wp_enqueue_style( 'nouislider_css', get_template_directory_uri() .'/css/nouislider.css');
			// nouislider.js
			wp_enqueue_script( 'nouislider_js', get_template_directory_uri() . '/js/nouislider.js', array(), null, true );	
			// nouislider script
			wp_enqueue_script( 'nouislider_script', get_template_directory_uri() . '/js/nouislider.script.js', array('jquery'), null, true );			
		}
		if( is_page_template('page-template/gallery-filtarable-popup.php') ||
			is_page_template('page-template/gallery-filtarable.php') || 
			is_page_template('page-template/gallery-popup.php') ){			
			// image load jquery.
			img_load();
			// image load script.
			wp_enqueue_script( 'church_load_image', get_template_directory_uri() . '/js/filter-script.js', array('jquery', 'church_images_loaded', 'church_masonry_js'), '', true  );
			// magnific popup css.
			wp_enqueue_style( 'church_magnific_css', get_template_directory_uri() . '/css/magnific-popup.css');	
			// magnific popup script.
			magnific_popup();
		}
		
		/* Singular Scripts ---------------------------------------------------*/

		if( is_single() || is_search() || is_archive() || is_singular() ) {
			// owl-script.
			owl_scripts();
		}		
		if( is_singular('sermon') || is_singular('ministry') || is_singular()  ){
			// magnific popup css
			wp_enqueue_style( 'church_magnific_css', get_template_directory_uri() . '/css/magnific-popup.css');	
			// magnific popup script.
			magnific_popup();
		}
		if( is_singular() ){
			// image load  jquery.
			img_load();
		}
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {			
			// Comment script
			wp_enqueue_script( 'comment-reply' );
		}
		endif;	
	 }
	 
	 add_action( 'wp_enqueue_scripts', 'church_scripts' );
}
/**
 * comment-class-filter
 */
if( !function_exists('church_avatar_css') ){

	 function church_avatar_css($class) {
		$class = str_replace("class='avatar", "class='img-responsive img-circle  avatar", $class) ;
		return $class;
	 }	 
	 add_filter('get_avatar','church_avatar_css');
}
/** 
 * Comment Reply link
 */
if( !function_exists('church_reply_link_class') ){

	 function church_reply_link_class($class){
	    $class = str_replace("class='comment-reply-link", "class='comment-reply-link btn btn-reply outline-btn outline-btn-red", $class);
	    return $class;
	 }	 
	 add_filter('comment_reply_link', 'church_reply_link_class');	 
} 
/**
 *  Comment Callback
 */
if( !function_exists('church_comment') ){

    function church_comment($comment, $args, $depth) {
		 
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		?>
		<li class="post pingback">
		  <p>
			<?php _e( 'Pingback:', 'praise_church' ); ?>
			<?php comment_author_link(); ?>
			<?php edit_comment_link( __( '(Edit)', 'praise_church' ), ' ' ); ?>
		  </p>
		  <?php
		 break;
		 default :
		?>        
		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		  <div id="comment-<?php comment_ID(); ?>" class="comment">
			<div class="media">
			  <div class="media-left comment-author vcard col-md-2"> <?php echo get_avatar( $comment, 118 ); ?> </div>
			  <!-- .comment-author .vcard -->
			  <div class="media-body comment-meta commentmetadata co-md-10">
				<h3 class="media-heading"> <?php printf(__('%s', 'praise_church'), sprintf('%s', get_comment_author_link())); ?> </h3>
				<p> <span> <i class="fa fa-calendar"></i>
				  <?php comment_time('d, F,Y');	?>
				  </span> <small> <?php echo human_time_diff( get_comment_time('U'), current_time('timestamp') ) . ' ago'; ?> </small>
				  <?php edit_comment_link( __( '(Edit)', 'praise_church' ), ' ' ); ?>
				</p>
				<div class="comment-content">
				  <?php comment_text(); ?>
				</div>
				<?php if ( $comment->comment_approved == '0' ) : ?>
				<em>
				<?php _e( 'Your comment is awaiting moderation.', 'praise_church' ); ?>
				</em> <br />
				<?php endif; ?>
				<div class="reply">
				  <?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</div>
				<!-- .reply -->
			  </div>
			  <!-- .comment-meta .commentmetadata -->
			</div>
		  </div>
		  <!-- #comment-## -->
    <?php
	break;
	endswitch;
   }	
}
/**
 * Theme option favicon.
 */
if( function_exists( 'wp_site_icon' ) ):   
if ( !function_exists( 'church_wp_head_script_favicon' ) || ! has_site_icon() ) { 
 
	  function church_wp_head_script_favicon(){
		 $style  = '';
		 $favicon = church_get_option('favicon');		 
		 if( $favicon != '' ) {
			$style = '<link rel="icon" type="image/png" href="'. esc_url( $favicon ) .'" > ' . "\n";		 
		 }		 
		 echo $style;
 	  }
	  add_action( 'wp_head', 'church_wp_head_script_favicon' );   
	  add_action( 'login_head', 'church_wp_head_script_favicon');
	  add_action( 'admin_head', 'church_wp_head_script_favicon');	  
} 
endif;
/**
 * Nav menu use last field.
 */
if( isset( $GLOBALS['church_walker'] ) ) : $GLOBALS['church_walker']++;
	else : $GLOBALS['church_walker'] = 1;
endif;


if(!function_exists('church_add_search_box') ){

	function church_add_search_box($items, $args) {
		if ( $GLOBALS['church_walker'] == 1 ) {
			$items .= '<li><a href="#" id="search" class="search"><i class="fa fa-search"></i></a></li>';
			$GLOBALS['church_walker']++;
		}
		return $items;
	}	 
	add_filter('wp_nav_menu_items','church_add_search_box', 10, 2);	 
}

	// Requred files
	$files = array(
		// Custom template tags for this theme. 
		"inc/template-tags",
		// Nav-menu.
		"inc/nav-menu-walker",
		// Theme-options & Meta-box.
		"framework/init",
		// Customizer additions.
		"inc/customizer",
		// Popular post widget.
		"inc/widget/popular_post",
		// Paypal Tranzaction.
		"framework/paypal/paypal_donate",
		// custom header.
		"inc/custom-header",
		// Plugin TGMA
		"tgm-plugin/class-tgm-plugin-activation",
		// Plugin TGMA
		"tgm-plugin/church-plugin",
		// Woocommerce.
		"inc/woocommerce/function-woocommerce",
	);
	
	foreach ( $files as $file ) {
	if ( file_exists( get_template_directory() . '/'. $file .'.php' ) )
			get_template_part( "{$file}" );
	}	
	

if(!function_exists( 'fn_church_ajaxurl')) {
	function fn_church_ajaxurl() {
	?>
    	<script type="text/javascript">	
		var fn_church_ajaxurl = '<?php echo admin_url('admin-ajax.php'); ?>';
	    </script>
	<?php
	}
	add_action('wp_head','fn_church_ajaxurl');
}

if(!function_exists( 'refresh_dynamic_contents')){
	function refresh_dynamic_contents() {
		global $woocommerce, $yith_wcwl;
		$data = array(
			'cart_count_products' => $woocommerce->cart->cart_contents_count,
			'wishlist_count_products' => yith_wcwl_count_products()
		);
		wp_send_json($data);
	}
	add_action( 'wp_ajax_refresh_dynamic_contents', 'refresh_dynamic_contents' );
	add_action( 'wp_ajax_nopriv_refresh_dynamic_contents', 'refresh_dynamic_contents' );
}

if(!function_exists( 'fn_church_ajax_added_to_cart' ) ){
	function fn_church_ajax_added_to_cart() {
		
		if(!function_exists( 'fn_church_shopping_bag_items_number' ) ){				
			function fn_church_shopping_bag_items_number( $fragments ) {
				
				global $woocommerce;
				ob_start(); ?>
		
				<script>
				(function($){
					$('.shopping-bag-button').trigger('click');
				})(jQuery);
				</script>
				
				<span class="shopping_bag_items_number"><?php echo esc_html($woocommerce->cart->cart_contents_count); ?></span>
		
				<?php
				$fragments['.shopping_bag_items_number'] = ob_get_clean();
				return $fragments;
			}
			add_filter('add_to_cart_fragments', 'fn_church_shopping_bag_items_number');
		}
	}
	add_action('woocommerce_ajax_added_to_cart', 'fn_church_ajax_added_to_cart');
}
?>